darkhistory.spec.pppc
=====================

.. automodule:: darkhistory.spec.pppc

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree: pppc

      get_pppc_spec


.. rubric:: Footnotes

.. [1] Marco Cirelli, Gennaro Corcella, Andi Hektor, Gert Hutsi, Mario Kadastik, Paolo Panci, Martti Raidal, Filippo Sala, and Alessandro Strumia, “PPPC 4 DM ID: A Poor Particle Physicist Cookbook for Dark Matter Indirect Detection,” JCAP 1103, 051 (2011), [Erratum: JCAP1210,E01(2012)], arXiv:1012.4515 [hep-ph].

.. [2] Paolo Ciafaloni, Denis Comelli, Antonio Riotto, Filippo Sala, Alessandro Strumia, et al., “Weak Corrections are Relevant for Dark Matter Indirect Detection,” JCAP 1103, 019 (2011), arXiv:1009.0224 [hep-ph]
   